Function cvar::console::visit [] [src]

pub fn visit<F>(root: &IVisit, f: F) where F: FnMut(Node)

Visits all nodes in the cvar hierarchy and invokes the callback with each Node.

The context for the parent nodes is unavailable, see walk(). This makes it not possible to reconstruct the node identifier.