Function cvar::console::walk
[−]
[src]
pub fn walk<F>(root: &IVisit, f: F) where F: FnMut(Walk, Node)Walks the cvar hierarchy while keeping track of the parent context.
The callback f accepts an iterable Walk context to retrieve the parent list nodes and a Node.